# If any of the following macros should be set otherwise,
# you can wrap any of them with the following conditions:
# - %%if 0%%{centos} == 7
# - %%if 0%%{?rhel} == 7
# - %%if 0%%{?fedora} == 23
# Or just test for particular distribution:
# - %%if 0%%{centos}
# - %%if 0%%{?rhel}
# - %%if 0%%{?fedora}
#
# Be aware, on centos, both %%rhel and %%centos are set. If you want to test
# rhel specific macros, you can use %%if 0%%{?rhel} && 0%%{?centos} == 0 condition.
# (Don't forget to replace double percentage symbol with single one in order to apply a condition)

# Generate devel rpm
%global with_devel 1
# Build project from bundled dependencies
%global with_bundled 0
# Build with debug info rpm
%global with_debug 0
# Run tests in check section
%global with_check 0
# Generate unit-test rpm
%global with_unit_test 1

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%if ! 0%{?gobuild:1}
%define gobuild(o:) go build -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n')" -a -v -x %{?**};
%endif

%global provider        github
%global provider_tld    com
%global project         elazarl
%global repo            goproxy
# https://github.com/elazarl/goproxy
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global commit          6016d2397298b0750eeb06f4d24e03cfd7e45c77
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           golang-%{provider}-%{project}-%{repo}
Version:        0
Release:        0.1.git%{shortcommit}%{?dist}
Summary:        An HTTP proxy library for Go
License:        BSD
URL:            https://%{provider_prefix}
Source0:        https://%{provider_prefix}/archive/%{commit}/%{repo}-%{shortcommit}.tar.gz

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  %{?go_arches:%{go_arches}}%{!?go_arches:%{ix86} x86_64 aarch64 %{arm}}
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}

%if ! 0%{?with_bundled}
# examples/goproxy-transparent/transparent.go
BuildRequires: golang(github.com/inconshreveable/go-vhost)

# Remaining dependencies not included in main packages
BuildRequires: golang(github.com/paulrosania/go-charset/charset)
BuildRequires: golang(github.com/paulrosania/go-charset/data)
%endif

%description
%{summary}

%if 0%{?with_devel}
%package devel
Summary:       %{summary}
BuildArch:     noarch

%if 0%{?with_check} && ! 0%{?with_bundled}
BuildRequires: golang(github.com/paulrosania/go-charset/charset)
BuildRequires: golang(github.com/paulrosania/go-charset/data)
%endif

Requires:      golang(github.com/paulrosania/go-charset/charset)
Requires:      golang(github.com/paulrosania/go-charset/data)

Provides:      golang(%{import_path}) = %{version}-%{release}
Provides:      golang(%{import_path}/ext/auth) = %{version}-%{release}
Provides:      golang(%{import_path}/ext/html) = %{version}-%{release}
Provides:      golang(%{import_path}/ext/image) = %{version}-%{release}
Provides:      golang(%{import_path}/regretable) = %{version}-%{release}
Provides:      golang(%{import_path}/transport) = %{version}-%{release}

%description devel
%{summary}

This package contains library source intended for
building other packages which use import path with
%{import_path} prefix.
%endif

%if 0%{?with_unit_test} && 0%{?with_devel}
%package unit-test-devel
Summary:         Unit tests for %{name} package
%if 0%{?with_check}
#Here comes all BuildRequires: PACKAGE the unit tests
#in %%check section need for running
%endif

# test subpackage tests code from devel subpackage
Requires:        %{name}-devel = %{version}-%{release}

%if 0%{?with_check} && ! 0%{?with_bundled}
%endif


%description unit-test-devel
%{summary}

This package contains unit tests for project
providing packages with %{import_path} prefix.
%endif

%prep
%setup -q -n %{repo}-%{commit}
# use foss fork
sed -i 's|rogpeppe/go-charset|paulrosania/go-charset|g' ext/html/html.go


%build
mkdir -p src/%{provider}.%{provider_tld}/%{project}
ln -s ../../../ src/%{import_path}

%if ! 0%{?with_bundled}
export GOPATH=$(pwd):%{gopath}
%else
# No dependency directories so far
export GOPATH=$(pwd):%{gopath}
%endif

#%gobuild -o bin/examples/goproxy-basic %{import_path}/examples/goproxy-basic
#%gobuild -o bin/examples/goproxy-eavesdropper %{import_path}/examples/goproxy-eavesdropper
#%gobuild -o bin/examples/goproxy-httpdump %{import_path}/examples/goproxy-httpdump
#%gobuild -o bin/examples/goproxy-jquery-version %{import_path}/examples/goproxy-jquery-version
#%gobuild -o bin/examples/goproxy-no-reddit-at-worktime %{import_path}/examples/goproxy-no-reddit-at-worktime
#%gobuild -o bin/examples/goproxy-sokeepalive %{import_path}/examples/goproxy-sokeepalive
#%gobuild -o bin/examples/goproxy-sslstrip %{import_path}/examples/goproxy-sslstrip
#%gobuild -o bin/examples/goproxy-stats %{import_path}/examples/goproxy-stats
#%gobuild -o bin/examples/goproxy-transparent %{import_path}/examples/goproxy-transparent
#%gobuild -o bin/examples/goproxy-upside-down-ternet %{import_path}/examples/goproxy-upside-down-ternet
#%gobuild -o bin/examples/goproxy-yui-minify %{import_path}/examples/goproxy-yui-minify

%install
install -d -p %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-basic %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-eavesdropper %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-httpdump %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-jquery-version %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-no-reddit-at-worktime %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-sokeepalive %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-sslstrip %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-stats %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-transparent %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-upside-down-ternet %{buildroot}%{_bindir}
#install -p -m 0755 bin/examples/goproxy-yui-minify %{buildroot}%{_bindir}

# source codes for building projects
%if 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
echo "%%dir %%{gopath}/src/%%{import_path}/." >> devel.file-list
# find all *.go but no *_test.go files and generate devel.file-list
for file in $(find . \( -iname "*.go" -or -iname "*.s" \) \! -iname "*_test.go") ; do
    dirprefix=$(dirname $file)
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$dirprefix
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> devel.file-list

    while [ "$dirprefix" != "." ]; do
        echo "%%dir %%{gopath}/src/%%{import_path}/$dirprefix" >> devel.file-list
        dirprefix=$(dirname $dirprefix)
    done
done
%endif

# testing files for this project
%if 0%{?with_unit_test} && 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
# find all *_test.go files and generate unit-test-devel.file-list
for file in $(find . -iname "*_test.go") ; do
    dirprefix=$(dirname $file)
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$dirprefix
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> unit-test-devel.file-list

    while [ "$dirprefix" != "." ]; do
        echo "%%dir %%{gopath}/src/%%{import_path}/$dirprefix" >> devel.file-list
        dirprefix=$(dirname $dirprefix)
    done
done
%endif

%if 0%{?with_devel}
sort -u -o devel.file-list devel.file-list
%endif

%check
%if 0%{?with_check} && 0%{?with_unit_test} && 0%{?with_devel}
%if ! 0%{?with_bundled}
export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%else
# No dependency directories so far

export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%endif

%if ! 0%{?gotest:1}
%global gotest go test
%endif

%gotest %{import_path}
%gotest %{import_path}/examples/goproxy-jquery-version
%gotest %{import_path}/ext/auth
%gotest %{import_path}/ext/html
%gotest %{import_path}/regretable
%endif

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md
#%{_bindir}/examples/goproxy-basic
#%{_bindir}/examples/goproxy-eavesdropper
#%{_bindir}/examples/goproxy-httpdump
#%{_bindir}/examples/goproxy-jquery-version
#%{_bindir}/examples/goproxy-no-reddit-at-worktime
#%{_bindir}/examples/goproxy-sokeepalive
#%{_bindir}/examples/goproxy-sslstrip
#%{_bindir}/examples/goproxy-stats
#%{_bindir}/examples/goproxy-transparent
#%{_bindir}/examples/goproxy-upside-down-ternet
#%{_bindir}/examples/goproxy-yui-minify

%if 0%{?with_devel}
%files devel -f devel.file-list
%license LICENSE
%doc README.md
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}
%endif

%if 0%{?with_unit_test} && 0%{?with_devel}
%files unit-test-devel -f unit-test-devel.file-list
%license LICENSE
%doc README.md
%endif

%changelog
* Sat Feb 04 2017 Tom Callaway <spot@fedoraproject.org> - 0-0.1.git6016d23
- First package for Fedora

